#ifndef STICKC_H
#define STICKC_H

#include <M5StickC.h>


class STICKC : public M5StickC
{
public:
	void begin(bool LCDEnable = true, bool PowerEnable = true, bool SerialEnable = true);
	void update(void);
	int16_t height(void);
    int16_t width(void);
	void setRotation(uint8_t r);
	void fillScreen(uint32_t color);	
	void drawPixel(int32_t x, int32_t y, uint32_t color);
	void drawLine(int32_t x0, int32_t y0, int32_t x1, int32_t y1, uint32_t color);
	void fillRect(int32_t x, int32_t y, int32_t w, int32_t h, uint32_t color);
	void drawRect(int32_t x, int32_t y, int32_t w, int32_t h, uint32_t color);
    void drawRoundRect(int32_t x0, int32_t y0, int32_t w, int32_t h, int32_t radius, uint32_t color);
    void fillRoundRect(int32_t x0, int32_t y0, int32_t w, int32_t h, int32_t radius, uint32_t color);
	void drawCircle(int32_t x0, int32_t y0, int32_t r, uint32_t color);
	void fillCircle(int32_t x0, int32_t y0, int32_t r, uint32_t color);
    void drawEllipse(int16_t x0, int16_t y0, int32_t rx, int32_t ry, uint16_t color);
    void fillEllipse(int16_t x0, int16_t y0, int32_t rx, int32_t ry, uint16_t color);
    void drawTriangle(int32_t x0, int32_t y0, int32_t x1, int32_t y1, int32_t x2, int32_t y2, uint32_t color);
    void fillTriangle(int32_t x0, int32_t y0, int32_t x1, int32_t y1, int32_t x2, int32_t y2, uint32_t color);
    void setCursor(int16_t x, int16_t y);
    void setTextColor(uint16_t fgcolor, uint16_t bgcolor);
    void setTextSize(uint8_t size);
	void setTextFont(uint8_t font);
	uint16_t color565(uint8_t red, uint8_t green, uint8_t blue);
	void printp(const char* str);
	void drawString(const char *string, int32_t poX, int32_t poY);
	
	void backlit(uint8_t brightness);
    void AXP_DisableAllIRQ(void);
    void AXP_ClearAllIRQ(void);
    void AXP_EnablePressIRQ(bool short_press, bool long_press);
    void AXP_GetPressIRQ(bool *short_press, bool *long_press);
    void AXP_ClearPressIRQ(bool short_press, bool long_press);
    void AXP_SetSleep(void);
    void AXP_DeepSleep(uint64_t time_in_us = 0);
    void AXP_LightSleep(uint64_t time_in_us = 0);
    void AXP_SetChargeVoltage(uint8_t);
    void AXP_SetChargeCurrent(uint8_t);
    void AXP_SetVOff(uint8_t voltage);
    float AXP_GetBatVoltage();
    float AXP_GetBatCurrent();
    float AXP_GetVinVoltage();
    float AXP_GetVinCurrent();
    float AXP_GetVBusVoltage();
    float AXP_GetVBusCurrent();
	float AXP_GetBatPower();
	void PowerOff();
	
	void LED_On();
	void LED_Off();
	uint8_t LED_getStatus();
	
	int IMU_Init(void);
	void IMU_getAccelAdc(int16_t *ax, int16_t *ay, int16_t *az);
    void IMU_getGyroAdc(int16_t *gx, int16_t *gy, int16_t *gz);
    void IMU_getTempAdc(int16_t *t);
    void IMU_getAccelData(float *ax, float *ay, float *az);
    void IMU_getGyroData(float *gx, float *gy, float *gz);
    void IMU_getTempData(float *t);
    void IMU_getAhrsData(float *pitch, float *roll, float *yaw);
	
    void RTC_SetTime(uint8_t Hours, uint8_t Minutes, uint8_t Seconds);
    void RTC_SetDate(uint8_t WeekDay, uint8_t Month, uint8_t Date, uint16_t Year);
    void RTC_GetTime(uint8_t *Hours, uint8_t *Minutes, uint8_t *Seconds);
    void RTC_GetDate(uint8_t *WeekDay, uint8_t *Month, uint8_t *Date, uint16_t *Year);
	
	uint8_t BtnA_isPressed();
    uint8_t BtnA_isReleased();
    uint8_t BtnA_wasPressed();
    uint8_t BtnA_wasReleased();
    uint8_t BtnA_pressedFor(uint32_t ms);
    uint8_t BtnA_releasedFor(uint32_t ms);
    uint8_t BtnA_wasReleasefor(uint32_t ms);
	uint8_t BtnB_isPressed();
    uint8_t BtnB_isReleased();
    uint8_t BtnB_wasPressed();
    uint8_t BtnB_wasReleased();
    uint8_t BtnB_pressedFor(uint32_t ms);
    uint8_t BtnB_releasedFor(uint32_t ms);
    uint8_t BtnB_wasReleasefor(uint32_t ms);
};


#endif
